#!/bin/sh

#
# Define our variables
#
export server=192.168.1.20                 # the IP address of your TapeTrack Server
export pw=                                 # the password for our connection to the TapeTrack Server
export user=tapemaster                     # the userid for our connection to the TapeTrack Server
export PATH=../bin:$PATH                   # add the bin directory to the path
export drfile=QP1ARCY995185.txt            # the name of our BRMS plan file
export repository=DR                       # the TapeTrack Repository we will use when recalling tapes in a DR
export description=My_BRMS_DR_Plan         # the description of our strategy
export customer=ACME                       # our TapeTrack Customer-ID
export media=LTO                           # our TapeTrack Media-ID
export expiry="*+30"                       # keep this strategy for 30 days from now

#
# Run the first step to extract the volume serials from the BRMS DR Plan file
#
echo "Running step 1 of 3 (Parsing BRMS DR File)"
TMSS10DRP_BRMS -uh < ../var/$drfile > ../var/brms_drplan.txt 2> ../var/drfileparse-messages.txt

#
# Run the second step to create the DR Strategy in TapeTrack
#
echo "Running step 2 of 3 (Creating strategy and uploading plan file)"
TMSS10DRStrategy -E $expiry -C $customer -A ../var/$drfile -S $user:-$pw@$server -d ../etc/BRMS.ttidef -R $repository -D $description < ../var/brms_drplan.txt > ../var/drstrategy-create-report.txt 2> ../var/drstrategy-create-messages.txt

#
# Run a DR Report
#
echo "Running step 3 of 3 (Producing DR Strategy Reports)"
TMSS10ListDRStrategies -S $user:-$pw@$server -C $customer > ../var/drstrategy-list-report.txt 2> ../var/drstrategy-list-messages.txt
